@@ -2,7 +2,8 @@
  * AT-SPI - Assistive Technology Service Provider Interface
  * (Gnome Accessibility Project; http://developer.gnome.org/projects/gap)
  *
- * Copyright 2001 Sun Microsystems Inc.
+ * Copyright 2001, 2002 Sun Microsystems Inc.,
+ * Copyright 2001, 2002 Ximian, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -149,4 +150,4 @@ spi_image_init (SpiImage *image)
 BONOBO_TYPE_FUNC_FULL (SpiImage,
 		       Accessibility_Image,
 		       SPI_TYPE_BASE,
-		       spi_image);
+		       spi_image)
